@@ -29,9 +29,6 @@
 #include <sys/time.h>
 #endif
 
-#ifndef INT64_FORMAT
-#define INT64_FORMAT "%" INT64_MODIFIER "d"
-#endif
 
 #define SLON_MEMDEBUG	1
 #ifndef false
@@ -61,6 +58,7 @@
  /* FIXME: must determine and use OS specific max path length */
  /* cbb: Not forcibly necessary; note that MAXPGPATH is 1024 */
 
+#define SLON_CLEANUP_SLEEP			600 /* sleep 10 minutes between */
  /* cleanup calls */
 #define SLON_VACUUM_FREQUENCY		3	/* vacuum every 3rd cleanup */
 
@@ -478,7 +476,6 @@ extern void rtcfg_storeSet(int set_id, int set_origin, char *set_comment);
 extern void rtcfg_dropSet(int set_id);
 extern void rtcfg_moveSet(int set_id, int old_origin, int new_origin,
 			  int sub_provider);
-extern void rtcfg_reloadSets(PGconn *db);
 
 extern void rtcfg_storeSubscribe(int sub_set, int sub_provider,
 					 char *sub_forward);
